@@ -1,6 +1,6 @@
 import sys
 
-from je_auto_control.utils.test_record.record_test_class import test_record
+from je_auto_control.utils.test_record.record_test_class import test_record_instance
 from je_auto_control.utils.exception.exceptions import HTMLException
 from je_auto_control.utils.exception.exception_tag import html_generate_no_data_tag
 from threading import Lock
@@ -134,11 +134,11 @@ def generate_html(html_name: str = "default_name") -> str:
     :param html_name: save html file name
     :return: html_string
     """
-    if len(test_record.total_record_list) == 0:
+    if len(test_record_instance.test_record_list) == 0:
         raise HTMLException(html_generate_no_data_tag)
     else:
         event_str = ""
-        for record_data in test_record.total_record_list:
+        for record_data in test_record_instance.test_record_list:
             # because data on record_data all is str
             if record_data.get("program_exception") == "None":
                 event_str = make_html_table(event_str, record_data, "event_table_head")
